-- NoIndex: true
local lib_path = reaper.GetExtState("Lokasenna_GUI", "lib_path_v2")
if not lib_path or lib_path == "" then
    reaper.MB("Couldn't load the Lokasenna_GUI library. Please run 'Script: Set Lokasenna_GUI v2 library path.lua' in your Action List.", "Whoops!", 0)
    return
end
loadfile(lib_path .. "Core.lua")()

local _, current_file = reaper.get_action_context()
local path = current_file:match("^(.+[\\/])[^/]+$")
if not path then
  GUI.Msg("Unable to get path to the UI module")
  return
end

local GUI_file = path .. "external gui test/gui elements.lua"
local create_GUI_elements, err = loadfile(GUI_file)
if err then
  GUI.Msg("Error loading " .. GUI_file .. "\n\n" .. err)
  return
end

create_GUI_elements()


------------------------------------
-------- Functions  ----------------
------------------------------------


GUI.elms.btn_go.func = function()

	-- Grab all of the user's settings into local variables,
	-- just to make it less awkward to work with
	local mode, thresh = GUI.Val("mnu_mode"), GUI.Val("sldr_thresh")
	local opts = GUI.Val("chk_opts")
	local time_sel, sel_track, glue = opts[1], opts[2], opts[3]

	-- Be nice, give the user an Undo point
	reaper.Undo_BeginBlock()

	reaper.ShowMessageBox(
		"This is where we pretend to perform some sort of fancy operation with the user's settings.\n\n"
		.."Working in "..tostring(GUI.elms.mnu_mode.optarray[mode])
		.." mode with a threshold of "..tostring(thresh).."db.\n\n"
		.."Apply only to time selection: "..tostring(time_sel).."\n"
		.."Apply only to selected track: "..tostring(sel_track).."\n"
		.."Glue the processed items together afterward: "..tostring(glue)
	, "Yay!", 0)


	reaper.Undo_EndBlock("Typical script options", 0)

	-- Exit the script on the next update
	GUI.quit = true

end


GUI.Init()
GUI.Main()
